app/bsky/feed/postgate library

Classes

DisableRule
Disables embedding of this post.
DisableRuleConverter
FeedPostgateRecord
Record defining interaction rules for a post. The record key (rkey) of the postgate record must match the record key of the post, and that record must be in the same repository.
FeedPostgateRecordConverter
UFeedPostgateEmbeddingRules
UFeedPostgateEmbeddingRulesConverter

Properties

disableRuleDescriptor → XRPCObjectDescriptor<DisableRule>
final
feedPostgateRecordDescriptor → XRPCRecordDescriptor<FeedPostgateRecord>
final