app/bsky/feed/threadgate/main library

Classes

FeedThreadgateRecord
Record defining interaction gating rules for a thread (aka, reply controls). The record key (rkey) of the threadgate record must match the record key of the thread's root post, and that record must be in the same repository.
FeedThreadgateRecordConverter

Extensions

FeedThreadgateRecordPatterns on FeedThreadgateRecord
Adds pattern-matching-related methods to FeedThreadgateRecord.