AdminGetInviteCodesInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

AdminGetInviteCodesInput({@AdminGetInviteCodesParametersSortConverter() AdminGetInviteCodesParametersSort? sort, @Default.new(100) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
AdminGetInviteCodesInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $AdminGetInviteCodesInputCopyWith<AdminGetInviteCodesInput>
Create a copy of AdminGetInviteCodesInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → String?
no setterinherited
hasCursor → bool

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCursor → bool

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputExtension extension

no setter
hasNotSort → bool

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputExtension extension

no setter
hasSort → bool

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputExtension extension

no setter
limit → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort → AdminGetInviteCodesParametersSort?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AdminGetInviteCodesInput value)) → TResult

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AdminGetInviteCodesInput value)?) → TResult?

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AdminGetInviteCodesInput value)?, {required TResult orElse()}) → TResult

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(AdminGetInviteCodesParametersSort? sort, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AdminGetInviteCodesInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(AdminGetInviteCodesParametersSort? sort, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(AdminGetInviteCodesParametersSort? sort, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on AdminGetInviteCodesInput, provided by the AdminGetInviteCodesInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>