AdminSendEmailInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

AdminSendEmailInput({required String recipientDid, required String content, String? subject, required String senderDid, String? comment, Map<String, dynamic>? $unknown})
const
factory
AdminSendEmailInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
comment → String?
Additional comment by the sender that won't be used in the email itself but helpful to provide more context for moderators/reviewers
no setterinherited
content → String
no setterinherited
copyWith → $AdminSendEmailInputCopyWith<AdminSendEmailInput>
Create a copy of AdminSendEmailInput with the given fields replaced by the non-null parameter values.
no setterinherited
hasComment → bool

Available on AdminSendEmailInput, provided by the AdminSendEmailInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on AdminSendEmailInput, provided by the AdminSendEmailInputExtension extension

no setter
hasNotSubject → bool

Available on AdminSendEmailInput, provided by the AdminSendEmailInputExtension extension

no setter
hasSubject → bool

Available on AdminSendEmailInput, provided by the AdminSendEmailInputExtension extension

no setter
recipientDid → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderDid → String
no setterinherited
subject → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AdminSendEmailInput value)) → TResult

Available on AdminSendEmailInput, provided by the AdminSendEmailInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AdminSendEmailInput value)?) → TResult?

Available on AdminSendEmailInput, provided by the AdminSendEmailInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AdminSendEmailInput value)?, {required TResult orElse()}) → TResult

Available on AdminSendEmailInput, provided by the AdminSendEmailInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String recipientDid, String content, String? subject, String senderDid, String? comment, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on AdminSendEmailInput, provided by the AdminSendEmailInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AdminSendEmailInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String recipientDid, String content, String? subject, String senderDid, String? comment, Map<String, dynamic>? $unknown)) → TResult

Available on AdminSendEmailInput, provided by the AdminSendEmailInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String recipientDid, String content, String? subject, String senderDid, String? comment, Map<String, dynamic>? $unknown)?) → TResult?

Available on AdminSendEmailInput, provided by the AdminSendEmailInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>