ModerationCreateReportInput class abstract

Available extensions
Annotations
  • @freezed

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ModerationCreateReportInputCopyWith<ModerationCreateReportInput>
Create a copy of ModerationCreateReportInput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasModTool → bool

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputExtension extension

no setter
hasNotModTool → bool

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputExtension extension

no setter
hasNotReason → bool

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputExtension extension

no setter
hasReason → bool

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputExtension extension

no setter
modTool → ModTool?
no setterinherited
reason → String?
Additional context about the content and violation.
no setterinherited
reasonType → ReasonType
Indicates the broad category of violation the report is for.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → UModerationCreateReportInputSubject
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModerationCreateReportInput value)) → TResult

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModerationCreateReportInput value)?) → TResult?

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModerationCreateReportInput value)?, {required TResult orElse()}) → TResult

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ReasonType reasonType, String? reason, UModerationCreateReportInputSubject subject, ModTool? modTool, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModerationCreateReportInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ReasonType reasonType, String? reason, UModerationCreateReportInputSubject subject, ModTool? modTool, Map<String, dynamic>? $unknown)) → TResult

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ReasonType reasonType, String? reason, UModerationCreateReportInputSubject subject, ModTool? modTool, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModerationCreateReportInput, provided by the ModerationCreateReportInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>