ServerCheckAccountStatusOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerCheckAccountStatusOutput({required bool activated, required bool validDid, required String repoCommit, required String repoRev, required int repoBlocks, required int indexedRecords, required int privateStateValues, required int expectedBlobs, required int importedBlobs, Map<String, dynamic>? $unknown})
const
factory
ServerCheckAccountStatusOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
activated → bool
no setterinherited
copyWith → $ServerCheckAccountStatusOutputCopyWith<ServerCheckAccountStatusOutput>
Create a copy of ServerCheckAccountStatusOutput with the given fields replaced by the non-null parameter values.
no setterinherited
expectedBlobs → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
importedBlobs → int
no setterinherited
indexedRecords → int
no setterinherited
isActivated → bool

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputExtension extension

no setter
isNotActivated → bool

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputExtension extension

no setter
isNotValidDid → bool

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputExtension extension

no setter
isValidDid → bool

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputExtension extension

no setter
privateStateValues → int
no setterinherited
repoBlocks → int
no setterinherited
repoCommit → String
no setterinherited
repoRev → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validDid → bool
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerCheckAccountStatusOutput value)) → TResult

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerCheckAccountStatusOutput value)?) → TResult?

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerCheckAccountStatusOutput value)?, {required TResult orElse()}) → TResult

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool activated, bool validDid, String repoCommit, String repoRev, int repoBlocks, int indexedRecords, int privateStateValues, int expectedBlobs, int importedBlobs, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerCheckAccountStatusOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool activated, bool validDid, String repoCommit, String repoRev, int repoBlocks, int indexedRecords, int privateStateValues, int expectedBlobs, int importedBlobs, Map<String, dynamic>? $unknown)) → TResult

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool activated, bool validDid, String repoCommit, String repoRev, int repoBlocks, int indexedRecords, int privateStateValues, int expectedBlobs, int importedBlobs, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerCheckAccountStatusOutput, provided by the ServerCheckAccountStatusOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>