ServerCreateSessionInput constructor
const
ServerCreateSessionInput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory ServerCreateSessionInput({
/// Handle or other identifier supported by the server for the authenticating user.
required String identifier,
required String password,
String? authFactorToken,
/// When true, instead of throwing error for takendown accounts, a valid response with a narrow scoped token will be returned
bool? allowTakendown,
Map<String, dynamic>? $unknown,
}) = _ServerCreateSessionInput;