ServerDeactivateAccountInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerDeactivateAccountInput({DateTime? deleteAfter, Map<String, dynamic>? $unknown})
const
factory
ServerDeactivateAccountInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ServerDeactivateAccountInputCopyWith<ServerDeactivateAccountInput>
Create a copy of ServerDeactivateAccountInput with the given fields replaced by the non-null parameter values.
no setterinherited
deleteAfter → DateTime?
A recommendation to server as to how long they should hold onto the deactivated account before deleting.
no setterinherited
hasDeleteAfter → bool

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotDeleteAfter → bool

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerDeactivateAccountInput value)) → TResult

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerDeactivateAccountInput value)?) → TResult?

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerDeactivateAccountInput value)?, {required TResult orElse()}) → TResult

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(DateTime? deleteAfter, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerDeactivateAccountInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(DateTime? deleteAfter, Map<String, dynamic>? $unknown)) → TResult

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(DateTime? deleteAfter, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerDeactivateAccountInput, provided by the ServerDeactivateAccountInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>