ServerGetSessionOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerGetSessionOutput({required String handle, required String did, Map<String, dynamic>? didDoc, String? email, bool? emailConfirmed, bool? emailAuthFactor, bool? active, @ServerGetSessionOutputStatusConverter() ServerGetSessionOutputStatus? status, Map<String, dynamic>? $unknown})
const
factory
ServerGetSessionOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
active → bool?
no setterinherited
copyWith → $ServerGetSessionOutputCopyWith<ServerGetSessionOutput>
Create a copy of ServerGetSessionOutput with the given fields replaced by the non-null parameter values.
no setterinherited
did → String
no setterinherited
didDoc → Map<String, dynamic>?
no setterinherited
email → String?
no setterinherited
emailAuthFactor → bool?
no setterinherited
emailConfirmed → bool?
no setterinherited
handle → String
no setterinherited
hasDidDoc → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
hasEmail → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotDidDoc → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
hasNotEmail → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
hasNotStatus → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
hasStatus → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
isActive → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
isEmailAuthFactor → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
isEmailConfirmed → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
isNotActive → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
isNotEmailAuthFactor → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
isNotEmailConfirmed → bool

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ServerGetSessionOutputStatus?
If active=false, this optional field indicates a possible reason for why the account is not active. If active=false and no status is supplied, then the host makes no claim for why the repository is no longer being hosted.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerGetSessionOutput value)) → TResult

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerGetSessionOutput value)?) → TResult?

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerGetSessionOutput value)?, {required TResult orElse()}) → TResult

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String handle, String did, Map<String, dynamic>? didDoc, String? email, bool? emailConfirmed, bool? emailAuthFactor, bool? active, ServerGetSessionOutputStatus? status, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerGetSessionOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String handle, String did, Map<String, dynamic>? didDoc, String? email, bool? emailConfirmed, bool? emailAuthFactor, bool? active, ServerGetSessionOutputStatus? status, Map<String, dynamic>? $unknown)) → TResult

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String handle, String did, Map<String, dynamic>? didDoc, String? email, bool? emailConfirmed, bool? emailAuthFactor, bool? active, ServerGetSessionOutputStatus? status, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerGetSessionOutput, provided by the ServerGetSessionOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>