ServerGetSessionOutput constructor
const
ServerGetSessionOutput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory ServerGetSessionOutput({
required String handle,
required String did,
Map<String, dynamic>? didDoc,
String? email,
bool? emailConfirmed,
bool? emailAuthFactor,
bool? active,
/// If active=false, this optional field indicates a possible reason for why the account is not active. If active=false and no status is supplied, then the host makes no claim for why the repository is no longer being hosted.
@ServerGetSessionStatusConverter() ServerGetSessionStatus? status,
Map<String, dynamic>? $unknown,
}) = _ServerGetSessionOutput;