com/atproto/sync/subscribe_repos/commit library

Classes

Commit
Represents an update of repository state. Note that empty commits are allowed, which include no repo data changes, but an update to rev and signature.
CommitConverter

Extensions

CommitExtension on Commit
CommitPatterns on Commit
Adds pattern-matching-related methods to Commit.