com/atproto/sync/subscribe_repos/sync library

Classes

Sync
Updates the repo to a new state, without necessarily including that state on the firehose. Used to recover from broken commit streams, data loss incidents, or in situations where upstream host does not know recent state of the repository.
SyncConverter

Extensions

SyncPatterns on Sync
Adds pattern-matching-related methods to Sync.