appBskyContactDefs top-level constant

Map<String, dynamic> const appBskyContactDefs

app.bsky.contact.defs

Implementation

const appBskyContactDefs = <String, dynamic>{
  "lexicon": 1,
  "id": "app.bsky.contact.defs",
  "defs": {
    "matchAndContactIndex": {
      "type": "object",
      "description":
          "Associates a profile with the positional index of the contact import input in the call to `app.bsky.contact.importContacts`, so clients can know which phone caused a particular match.",
      "required": ["match", "contactIndex"],
      "properties": {
        "match": {
          "type": "ref",
          "description": "Profile of the matched user.",
          "ref": "app.bsky.actor.defs#profileView",
        },
        "contactIndex": {
          "type": "integer",
          "description": "The index of this match in the import contact input.",
          "minimum": 0,
          "maximum": 999,
        },
      },
    },
    "syncStatus": {
      "type": "object",
      "required": ["syncedAt", "matchesCount"],
      "properties": {
        "syncedAt": {
          "type": "string",
          "format": "datetime",
          "description": "Last date when contacts where imported.",
        },
        "matchesCount": {
          "type": "integer",
          "description":
              "Number of existing contact matches resulting of the user imports and of their imported contacts having imported the user. Matches stop being counted when the user either follows the matched contact or dismisses the match.",
          "minimum": 0,
        },
      },
    },
    "notification": {
      "type": "object",
      "description":
          "A stash object to be sent via bsync representing a notification to be created.",
      "required": ["from", "to"],
      "properties": {
        "from": {
          "type": "string",
          "format": "did",
          "description": "The DID of who this notification comes from.",
        },
        "to": {
          "type": "string",
          "format": "did",
          "description": "The DID of who this notification should go to.",
        },
      },
    },
  },
};