toolsOzoneReportDefs top-level constant

Map<String, dynamic> const toolsOzoneReportDefs

tools.ozone.report.defs

Implementation

const toolsOzoneReportDefs = <String, dynamic>{
  "lexicon": 1,
  "id": "tools.ozone.report.defs",
  "defs": {
    "reasonType": {
      "type": "string",
      "knownValues": [
        "tools.ozone.report.defs#reasonAppeal",
        "tools.ozone.report.defs#reasonOther",
        "tools.ozone.report.defs#reasonViolenceAnimal",
        "tools.ozone.report.defs#reasonViolenceThreats",
        "tools.ozone.report.defs#reasonViolenceGraphicContent",
        "tools.ozone.report.defs#reasonViolenceGlorification",
        "tools.ozone.report.defs#reasonViolenceExtremistContent",
        "tools.ozone.report.defs#reasonViolenceTrafficking",
        "tools.ozone.report.defs#reasonViolenceOther",
        "tools.ozone.report.defs#reasonSexualAbuseContent",
        "tools.ozone.report.defs#reasonSexualNCII",
        "tools.ozone.report.defs#reasonSexualDeepfake",
        "tools.ozone.report.defs#reasonSexualAnimal",
        "tools.ozone.report.defs#reasonSexualUnlabeled",
        "tools.ozone.report.defs#reasonSexualOther",
        "tools.ozone.report.defs#reasonChildSafetyCSAM",
        "tools.ozone.report.defs#reasonChildSafetyGroom",
        "tools.ozone.report.defs#reasonChildSafetyPrivacy",
        "tools.ozone.report.defs#reasonChildSafetyHarassment",
        "tools.ozone.report.defs#reasonChildSafetyOther",
        "tools.ozone.report.defs#reasonHarassmentTroll",
        "tools.ozone.report.defs#reasonHarassmentTargeted",
        "tools.ozone.report.defs#reasonHarassmentHateSpeech",
        "tools.ozone.report.defs#reasonHarassmentDoxxing",
        "tools.ozone.report.defs#reasonHarassmentOther",
        "tools.ozone.report.defs#reasonMisleadingBot",
        "tools.ozone.report.defs#reasonMisleadingImpersonation",
        "tools.ozone.report.defs#reasonMisleadingSpam",
        "tools.ozone.report.defs#reasonMisleadingScam",
        "tools.ozone.report.defs#reasonMisleadingElections",
        "tools.ozone.report.defs#reasonMisleadingOther",
        "tools.ozone.report.defs#reasonRuleSiteSecurity",
        "tools.ozone.report.defs#reasonRuleProhibitedSales",
        "tools.ozone.report.defs#reasonRuleBanEvasion",
        "tools.ozone.report.defs#reasonRuleOther",
        "tools.ozone.report.defs#reasonSelfHarmContent",
        "tools.ozone.report.defs#reasonSelfHarmED",
        "tools.ozone.report.defs#reasonSelfHarmStunts",
        "tools.ozone.report.defs#reasonSelfHarmSubstances",
        "tools.ozone.report.defs#reasonSelfHarmOther",
      ],
    },
    "reasonAppeal": {
      "type": "token",
      "description": "Appeal a previously taken moderation action",
    },
    "reasonOther": {
      "type": "token",
      "description": "An issue not included in these options",
    },
    "reasonViolenceAnimal": {
      "type": "token",
      "description": "Animal welfare violations",
    },
    "reasonViolenceThreats": {
      "type": "token",
      "description": "Threats or incitement",
    },
    "reasonViolenceGraphicContent": {
      "type": "token",
      "description": "Graphic violent content",
    },
    "reasonViolenceGlorification": {
      "type": "token",
      "description": "Glorification of violence",
    },
    "reasonViolenceExtremistContent": {
      "type": "token",
      "description":
          "Extremist content. These reports will be sent only be sent to the application's Moderation Authority.",
    },
    "reasonViolenceTrafficking": {
      "type": "token",
      "description": "Human trafficking",
    },
    "reasonViolenceOther": {
      "type": "token",
      "description": "Other violent content",
    },
    "reasonSexualAbuseContent": {
      "type": "token",
      "description": "Adult sexual abuse content",
    },
    "reasonSexualNCII": {
      "type": "token",
      "description": "Non-consensual intimate imagery",
    },
    "reasonSexualDeepfake": {
      "type": "token",
      "description": "Deepfake adult content",
    },
    "reasonSexualAnimal": {
      "type": "token",
      "description": "Animal sexual abuse",
    },
    "reasonSexualUnlabeled": {
      "type": "token",
      "description": "Unlabelled adult content",
    },
    "reasonSexualOther": {
      "type": "token",
      "description": "Other sexual violence content",
    },
    "reasonChildSafetyCSAM": {
      "type": "token",
      "description":
          "Child sexual abuse material (CSAM). These reports will be sent only be sent to the application's Moderation Authority.",
    },
    "reasonChildSafetyGroom": {
      "type": "token",
      "description":
          "Grooming or predatory behavior. These reports will be sent only be sent to the application's Moderation Authority.",
    },
    "reasonChildSafetyPrivacy": {
      "type": "token",
      "description": "Privacy violation involving a minor",
    },
    "reasonChildSafetyHarassment": {
      "type": "token",
      "description": "Harassment or bullying of minors",
    },
    "reasonChildSafetyOther": {
      "type": "token",
      "description":
          "Other child safety. These reports will be sent only be sent to the application's Moderation Authority.",
    },
    "reasonHarassmentTroll": {"type": "token", "description": "Trolling"},
    "reasonHarassmentTargeted": {
      "type": "token",
      "description": "Targeted harassment",
    },
    "reasonHarassmentHateSpeech": {
      "type": "token",
      "description": "Hate speech",
    },
    "reasonHarassmentDoxxing": {"type": "token", "description": "Doxxing"},
    "reasonHarassmentOther": {
      "type": "token",
      "description": "Other harassing or hateful content",
    },
    "reasonMisleadingBot": {
      "type": "token",
      "description": "Fake account or bot",
    },
    "reasonMisleadingImpersonation": {
      "type": "token",
      "description": "Impersonation",
    },
    "reasonMisleadingSpam": {"type": "token", "description": "Spam"},
    "reasonMisleadingScam": {"type": "token", "description": "Scam"},
    "reasonMisleadingElections": {
      "type": "token",
      "description": "False information about elections",
    },
    "reasonMisleadingOther": {
      "type": "token",
      "description": "Other misleading content",
    },
    "reasonRuleSiteSecurity": {
      "type": "token",
      "description": "Hacking or system attacks",
    },
    "reasonRuleProhibitedSales": {
      "type": "token",
      "description": "Promoting or selling prohibited items or services",
    },
    "reasonRuleBanEvasion": {
      "type": "token",
      "description": "Banned user returning",
    },
    "reasonRuleOther": {"type": "token", "description": "Other"},
    "reasonSelfHarmContent": {
      "type": "token",
      "description": "Content promoting or depicting self-harm",
    },
    "reasonSelfHarmED": {"type": "token", "description": "Eating disorders"},
    "reasonSelfHarmStunts": {
      "type": "token",
      "description": "Dangerous challenges or activities",
    },
    "reasonSelfHarmSubstances": {
      "type": "token",
      "description": "Dangerous substances or drug abuse",
    },
    "reasonSelfHarmOther": {
      "type": "token",
      "description": "Other dangerous content",
    },
  },
};