CommunicationCreateTemplateInput constructor
const
CommunicationCreateTemplateInput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory CommunicationCreateTemplateInput({
/// Name of the template.
required String name,
/// Content of the template, markdown supported, can contain variable placeholders.
required String contentMarkdown,
/// Subject of the message, used in emails.
required String subject,
/// Message language.
String? lang,
/// DID of the user who is creating the template.
String? createdBy,
Map<String, dynamic>? $unknown,
}) = _CommunicationCreateTemplateInput;