appBskyContactDismissMatch top-level constant
app.bsky.contact.dismissMatch
Implementation
const appBskyContactDismissMatch = <String, dynamic>{
"lexicon": 1,
"id": "app.bsky.contact.dismissMatch",
"defs": {
"main": {
"type": "procedure",
"description":
"Removes a match that was found via contact import. It shouldn't appear again if the same contact is re-imported. Requires authentication.",
"input": {
"encoding": "application/json",
"schema": {
"type": "object",
"required": ["subject"],
"properties": {
"subject": {
"type": "string",
"format": "did",
"description": "The subject's DID to dismiss the match with.",
},
},
},
},
"output": {
"encoding": "application/json",
"schema": {"type": "object", "properties": {}},
},
"errors": [
{"name": "InvalidDid"},
{"name": "InternalError"},
],
},
},
};