appBskyContactStartPhoneVerification top-level constant
app.bsky.contact.startPhoneVerification
Implementation
const appBskyContactStartPhoneVerification = <String, dynamic>{
"lexicon": 1,
"id": "app.bsky.contact.startPhoneVerification",
"defs": {
"main": {
"type": "procedure",
"description":
"Starts a phone verification flow. The phone passed will receive a code via SMS that should be passed to `app.bsky.contact.verifyPhone`. Requires authentication.",
"input": {
"encoding": "application/json",
"schema": {
"type": "object",
"required": ["phone"],
"properties": {
"phone": {
"type": "string",
"description": "The phone number to receive the code via SMS.",
},
},
},
},
"output": {
"encoding": "application/json",
"schema": {"type": "object", "properties": {}},
},
"errors": [
{"name": "RateLimitExceeded"},
{"name": "InvalidDid"},
{"name": "InvalidPhone"},
{"name": "InternalError"},
],
},
},
};